<?php
namespace Ak\Wp\Init;

use Ak\Wp\Core\TranslationLoader;
use Psr\Container\ContainerInterface;
use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;
use Psr\Http\Server\MiddlewareInterface;
use Psr\Http\Server\RequestHandlerInterface;
use WP_Locale;
use WP_Locale_Switcher;

/**
 * Class L10n
 *
 * @package Ak\Wp\Init
 */
final class L10n implements MiddlewareInterface
{
    /**
     * Process an incoming server request and return a response, optionally delegating
     * response creation to a handler.
     *
     * @param ServerRequestInterface $request
     * @param RequestHandlerInterface $handler
     * @return ResponseInterface
     */
    public function process(ServerRequestInterface $request, RequestHandlerInterface $handler): ResponseInterface
    {
        /** @var ContainerInterface $container */
        $container = $request->getAttribute('container');
        $config = $container->get('config')['wp'] ?? [];

        /** @var TranslationLoader $loader */
        $loader = $container->get('wp.translation_loader');
        add_filter('override_load_textdomain', [$loader, 'override_load_textdomain'], 10, 3);

        $GLOBALS['l10n'] = [];
        $GLOBALS['l10n_unloaded'] = [];

        // Define WP_LANG_DIR if not set.
        wp_set_lang_dir();

        // Load the default text localization domain.
        $this->load_default_textdomain($loader, $config['locale'] ?? 'hr');

        /**
         * WordPress Locale object for loading locale domain date and various strings.
         * @global WP_Locale $wp_locale
         * @since 2.1.0
         */
        $GLOBALS['wp_locale'] = new WP_Locale();

        /**
         *  WordPress Locale Switcher object for switching locales.
         *
         * @since 4.7.0
         *
         * @global WP_Locale_Switcher $wp_locale_switcher WordPress locale switcher object.
         */
        $GLOBALS['wp_locale_switcher'] = new WP_Locale_Switcher();
        $GLOBALS['wp_locale_switcher']->init();

        return $handler->handle($request);
    }

    /**
     * Load the default text localization domain.
     *
     * @param TranslationLoader $loader
     * @param string $locale
     */
    private function load_default_textdomain(TranslationLoader $loader, string $locale): void
    {
        unload_textdomain('default');

        $loader->load_textdomain('default', WP_LANG_DIR . "/{$locale}.mo");

        if (wp_installing()) {
            $loader->load_textdomain('default', WP_LANG_DIR . "/admin-{$locale}.mo");
        }
    }

}