<?php
namespace Ak\Wp\Init;

use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;
use Psr\Http\Server\MiddlewareInterface;
use Psr\Http\Server\RequestHandlerInterface;
use WP;
use WP_Embed;
use WP_Query;
use WP_Rewrite;
use WP_Roles;
use WP_Widget_Factory;

/**
 * Class WordPress
 *
 * @package Ak\Wp\Init
 */
final class WordPress implements MiddlewareInterface
{
    /**
     * Process an incoming server request and return a response, optionally delegating
     * response creation to a handler.
     *
     * @param ServerRequestInterface $request
     * @param RequestHandlerInterface $handler
     * @return ResponseInterface
     */
    public function process(ServerRequestInterface $request, RequestHandlerInterface $handler): ResponseInterface
    {

        $GLOBALS['wp_embed'] = new WP_Embed();

        /**
         * WordPress Query object
         * @global WP_Query $wp_the_query
         * @since 2.0.0
         */
        $GLOBALS['wp_the_query'] = new WP_Query();

        /**
         * Holds the reference to @see $wp_the_query
         * Use this global for WordPress queries
         * @global WP_Query $wp_query
         * @since 1.5.0
         */
        $GLOBALS['wp_query'] = $GLOBALS['wp_the_query'];

        /**
         * Holds the WordPress Rewrite object for creating pretty URLs
         * @global WP_Rewrite $wp_rewrite
         * @since 1.5.0
         */
        $GLOBALS['wp_rewrite'] = new WP_Rewrite();

        /**
         * WordPress Object
         * @global WP $wp
         * @since 2.0.0
         */
        $GLOBALS['wp'] = new WP();

        /**
         * WordPress Widget Factory Object
         * @global WP_Widget_Factory $wp_widget_factory
         * @since 2.8.0
         */
        $GLOBALS['wp_widget_factory'] = new WP_Widget_Factory();

        /**
         * WordPress User Roles
         * @global WP_Roles $wp_roles
         * @since 2.0.0
         */
        $GLOBALS['wp_roles'] = new WP_Roles();

        // Set internal encoding.
        wp_set_internal_encoding();

        register_shutdown_function('shutdown_action_hook');

        wp_scripts();

        // Make taxonomies and posts available to plugins and themes.
        // @plugin authors: warning: these get registered again on the init hook.
        create_initial_taxonomies();
        create_initial_post_types();

        return $handler->handle($request);
    }
}