<?php
namespace Ak\Wp\Plugin;

/**
 * Učitava sve registrirane pluginove.
 *
 * @package Ak\Wp\Plugin
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/wp-core
 */
class PluginLoader
{
    /** @var array */
    private $config;
    /** @var PluginManager */
    private $plugins;
    /** @var PluginInterface[] */
    private $loaded;

    /**
     * Koonstruktor.
     *
     * @param PluginManager $plugins
     * @param array $config
     */
    public function __construct(PluginManager $plugins, array $config = [])
    {
        $this->config = $config;
        $this->plugins = $plugins;
    }

    /**
     * Ovo je zadnja akcija prije nego što WordPress počne učitavati svoje pluginove.
     */
    public function register(): void
    {
        add_action('plugins_loaded', [$this, 'loadPlugins']);
    }

    /**
     * Prije nego što WordPress učita klasične pluginove, učitavamo naše.
     */
    public function loadPlugins(): void
    {
        foreach (($this->config['plugins'] ?? []) as $key => $value) {
            if (false === $value) {
                continue;
            }

            $name = is_numeric($key) ? $value : $key;

            if (
                isset($this->loaded[$name])
                || (isset($this->config['plugins'][$name]) && false === $this->config['plugins'][$name])
            ) {
                continue;
            }

            $plugin = $this->plugins->get($name);

            if ($plugin instanceof PluginInterface) {
                $plugin->attach();
            }

            $this->loaded[$name] = $plugin;
        }
    }
}