<?php
namespace Ak\Wp\Shortcode;

use Laminas\Cache\Storage\StorageInterface;

/**
 * Class CacheableShortcode
 *
 * @package Ak\Wp\Shortcode
 */
final class CacheableShortcodeWrapper implements ShortcodeInterface
{
    /** @var StorageInterface */
    private $cache;
    /** @var callable */
    private $callback;

    /**
     * CacheableShortcode constructor.
     * @param StorageInterface $cache
     * @param callable $callback
     */
    public function __construct(StorageInterface $cache, callable $callback)
    {
        $this->cache = $cache;
        $this->callback = $callback;
    }

    /**
     * Vraća renderirani HTML.
     *
     * @param array|string $atts
     * @param string|null $content
     *
     * @return string
     */
    public function render($atts, string $content = null): string
    {
        $atts = (array) $atts;
        ksort($atts);
        $cacheKey = md5(implode(';', $atts) . $content);

        if ($this->cache->hasItem($cacheKey)) {
            $rendered = $this->cache->getItem($cacheKey);
            if ($rendered) return $rendered;
        }

        $rendered = call_user_func_array($this->callback, [$atts, $content]);
        $this->cache->setItem($cacheKey, $rendered);

        return $rendered ?? '';
    }
}
