<?php
/**
 * Funkcije za inicijalizaciju WordPressa.
 */
use Ak\Db\Adapter\AdapterConfigFactory;
use Ak\Wp\Init\BaseUrl;
use Psr\Container\ContainerInterface;
use Psr\Http\Message\ServerRequestInterface;
use Laminas\Diactoros\ServerRequestFactory;

/**
 * Postavlja okruženje iz wp-config.php.
 *
 * @param ContainerInterface $container
 */
function wp_config(ContainerInterface $container): void
{
    $GLOBALS['container'] = $container;

    wp_paths();
    wp_urls();

    wp_db_config($container);
    wp_auth_config($container);
    wp_debug_config($container);
}

/**
 * Postavlja putanje do WordPress komponenti.
 */
function wp_paths(): void
{
    define('WP_CONTENT_DIR', dirname(ABSPATH) . '/wp-content');
}

/**
 * Postavlja URL-ove do stvari.
 *
 * @param ServerRequestInterface|null $request
 */
function wp_urls(ServerRequestInterface $request = null): void
{
    if (null === $request) {
        $request = ServerRequestFactory::fromGlobals();
    }

    if (!($baseUrl = $request->getAttribute('base_url'))) {
        $baseUrl = (new BaseUrl())->detectBaseUrl($request);
        $baseUrl = preg_replace('#/wp(/wp-admin)?$#', '', $baseUrl);
    }

    $uri = $request->getUri()
        ->withPath($baseUrl)
        ->withQuery('');

    define('WP_HOME', (string) $uri);
    define('WP_SITEURL', WP_HOME . '/wp');
    define('WP_CONTENT_URL', WP_HOME . '/wp-content');
}

/**
 * Postavlja podatke za spajanje na WordPress bazu.
 *
 * @param ContainerInterface $container
 */
function wp_db_config(ContainerInterface $container): void
{
    $wpConfig = $container->get('config')['wp'] ?? [];
    $configFactory = new AdapterConfigFactory();
    /** @noinspection PhpParamsInspection */
    $dbConfig = $configFactory($container, $wpConfig['db_adapter'] ?? 'db');

    define('DB_NAME', $dbConfig['database'] ?? '');
    define('DB_USER', $dbConfig['username'] ?? '');
    define('DB_PASSWORD', $dbConfig['password']);
    define('DB_HOST', $dbConfig['hostname'] ?? 'localhost');
    define('DB_CHARSET', 'utf8mb4');
    define('DB_COLLATE', 'utf8mb4_general_ci');

    $GLOBALS['table_prefix'] = 'wp_';
}

/**
 * Postavlja ključeve za autorizaciju.
 *
 * @param ContainerInterface $container
 */
function wp_auth_config(ContainerInterface $container): void
{
    $wpConfig = $container->get('config')['wp'] ?? [];
    $authConfig = $wpConfig['auth_keys'];

    define('AUTH_KEY', $authConfig['auth_key'] ?? '');
    define('SECURE_AUTH_KEY', $authConfig['secure_auth_key'] ?? '');
    define('LOGGED_IN_KEY', $authConfig['logged_in_key'] ?? '');
    define('NONCE_KEY', $authConfig['nonce_key'] ?? '');
    define('AUTH_SALT', $authConfig['auth_salt'] ?? '');
    define('SECURE_AUTH_SALT', $authConfig['secure_auth_salt'] ?? '');
    define('LOGGED_IN_SALT', $authConfig['logged_in_salt'] ?? '');
    define('NONCE_SALT', $authConfig['nonce_salt'] ?? '');
}

/**
 * Postavlja debug konstante.
 *
 * @param ContainerInterface $container
 */
function wp_debug_config(ContainerInterface $container): void
{
    $config = $container->get('config');
    $wpConfig = $config['wp'] ?? [];

    define('WP_DEBUG', $wpConfig['debug'] ?? false);
}

/**
 * Ubijene funkcije
 */
function load_tgm_plugin_activation(): void { }
function wp_install_defaults(): void { }
function wp_new_blog_notification($blog_title, $blog_url, $user_id, $password) { }
